@@ -95,7 +95,9 @@ class WeycopClient:
         top_p: Optional[float] = None,
         max_tokens: Optional[int] = None,
         stop: Optional[Union[str, List[str]]] = None,
-        stream: bool = False
+        stream: bool = False,
+        reasoning_effort: Optional[str] = None,
+        verbosity: Optional[str] = None
     ) -> ChatCompletion:
         """
         Create a chat completion
@@ -109,6 +111,8 @@ class WeycopClient:
             max_tokens: Maximum tokens to generate
             stop: Stop sequences
             stream: Whether to stream the response
+            reasoning_effort: GPT-5 reasoning effort level ("minimal", "low", "medium", "high"). Only applies to GPT-5 models
+            verbosity: GPT-5 verbosity level ("low", "medium", "high"). Only applies to GPT-5 models
             
         Returns:
             ChatCompletion object
@@ -142,6 +146,10 @@ class WeycopClient:
             payload["max_tokens"] = max_tokens
         if stop is not None:
             payload["stop"] = stop
+        if reasoning_effort is not None:
+            payload["reasoning_effort"] = reasoning_effort
+        if verbosity is not None:
+            payload["verbosity"] = verbosity
         
         response_data = self._make_request("POST", "/v1/chat/completions", json=payload)
         
@@ -401,23 +409,29 @@ class AsyncWeycopClient:
         self,
         model: str,
         messages: List[Union[Message, Dict[str, str]]],
+        provider: Optional[str] = None,
         temperature: Optional[float] = None,
         top_p: Optional[float] = None,
         max_tokens: Optional[int] = None,
         stop: Optional[Union[str, List[str]]] = None,
-        stream: bool = False
+        stream: bool = False,
+        reasoning_effort: Optional[str] = None,
+        verbosity: Optional[str] = None
     ) -> ChatCompletion:
         """
         Create a chat completion (async)
         
         Args:
-            model: Model name
+            model: Model name (e.g., "qwen3:4b-instruct", "gpt-4o", "claude-3-5-sonnet-20241022")
             messages: List of messages
+            provider: AI provider ("local", "openai", "anthropic"). If not specified, auto-detected from model name
             temperature: Sampling temperature (0-2)
             top_p: Nucleus sampling parameter (0-1)
             max_tokens: Maximum tokens to generate
             stop: Stop sequences
             stream: Whether to stream the response
+            reasoning_effort: GPT-5 reasoning effort level ("minimal", "low", "medium", "high"). Only applies to GPT-5 models
+            verbosity: GPT-5 verbosity level ("low", "medium", "high"). Only applies to GPT-5 models
             
         Returns:
             ChatCompletion object
@@ -438,6 +452,10 @@ class AsyncWeycopClient:
             "stream": stream
         }
         
+        # Add provider if specified
+        if provider is not None:
+            payload["provider"] = provider
+        
         # Add optional parameters
         if temperature is not None:
             payload["temperature"] = temperature
@@ -447,6 +465,10 @@ class AsyncWeycopClient:
             payload["max_tokens"] = max_tokens
         if stop is not None:
             payload["stop"] = stop
+        if reasoning_effort is not None:
+            payload["reasoning_effort"] = reasoning_effort
+        if verbosity is not None:
+            payload["verbosity"] = verbosity
         
         response_data = await self._make_request("POST", "/v1/chat/completions", json=payload)
         
